<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform>Verifizierung fehlgeschlagen, nur noch %n Chancen übrig</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung fehlgeschlagen, nur noch eine Chance übrig</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Gerät nicht verfügbar!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifizieren Sie Ihren Fingerabdruck</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifizierung fehlgeschlagen, nur noch %n Chance übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, nur noch %n Chancen übrig</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung fehlgeschlagen, nur noch eine Chance übrig</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Fingerabdruck gesperrt, bitte Passwort verwenden</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifizierung fehlgeschlagen, nur noch %n Chance übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, nur noch %n Chancen übrig</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung fehlgeschlagen, nur noch eine Chance übrig</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifizierung fehlgeschlagen, nur noch %n Chance übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, nur noch %n Chancen übrig</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung fehlgeschlagen, nur noch eine Chance übrig</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Falsches Passwort</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Bitte versuchen Sie es 1 Minute später erneut</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Bitte versuchen Sie es 1 Minute später erneut</numerusform><numerusform>Bitte versuchen Sie es %n Minuten später erneut</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Passwort zurücksetzen</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Passwort vergessen?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Bitte versuchen Sie es 1 Minute später erneut</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Bitte versuchen Sie es 1 Minute später erneut</numerusform><numerusform>Bitte versuchen Sie es %n Minuten später erneut</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Passwort zurücksetzen</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Passwort vergessen?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifizierung fehlgeschlagen, nur noch 1 Chance übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, nur noch %n Chancen übrig</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung fehlgeschlagen, nur noch eine Chance übrig</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Falsche PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey ist erforderlich</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Geben Sie Ihre PIN ein</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Bitte versuchen Sie es 1 Minute später erneut</numerusform><numerusform>Bitte versuchen Sie es %n Minute(n) später erneut</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Bitte versuchen Sie es 1 Minute später erneut</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Bitte versuchen Sie es 1 Minute später erneut</numerusform><numerusform>Bitte versuchen Sie es %n Minuten später erneut</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Passwort abgelaufen, bitte ändern</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Falsches Konto</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Falsches Passwort</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation>Standardmodus</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bildschirm sperren</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Bildschirm konnte nicht gesperrt werden</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Fingerabdruck-Überprüfung abgelaufen, bitte geben Sie Ihr Passwort manuell ein. </translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Fingerabdruck stimmt nicht überein</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Die oben genannten Benutzer sind immer noch angemeldet und es gehen Daten durch das Herunterfahren verloren. Sind Sie sicher, dass Sie das System herunterfahren möchten?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Die oben genannten Benutzer sind immer noch angemeldet und es gehen Daten durch einen Neustart verloren. Sind Sie sicher, dass Sie einen Neustart durchführen möchten?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Sie haben die Systemsicherheitsstufe auf hoch gesetzt, weshalb nicht zum Wayland-Modus gewechselt werden kann. Bitte deaktivieren Sie die hohe Systemsicherheitsstufe im Sicherheitszentrum und versuchen Sie es erneut.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neu starten</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Bereitschaftszustand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Sperren</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Benutzer wechseln</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>System wechseln</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Aktualisieren und herunterfahren</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Aktualisieren und neu starten</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Systemmonitor starten</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Die Programme verhindern das Herunterfahren des Computers und das Erzwingen des Herunterfahrens kann zu Datenverlust führen.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Klicken Sie zum Schließen des Programms auf Abbrechen und schließen Sie danach das Programm.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Die Programme verhindern einen Neustart des Computers und das Erzwingen eines Neustarts kann zu Datenverlust führen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Die Programme verhindern den Bereitschaftszustand des Computers und das Erzwingen des Bereitschaftszustand kann zu Datenverlust führen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Die Programme verhindern den Ruhezustand des Computers und das Erzwingen des Ruhezustands kann zu Datenverlust führen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Die Programme verhindern das Abmelden vom Computer und das Erzwingen der Abmeldung kann zu Datenverlust führen.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neu starten</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Bereitschaftszustand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Sind Sie sicher, dass Sie Herunterfahren möchten?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Sind Sie sicher, dass Sie neu starten möchten?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sind Sie sicher, dass Sie sich abmelden möchten?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Aktualisieren und herunterfahren</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Aktualisieren und neu starten</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation>Automatische Anmeldung</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Einschalten</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Ausschalten</translation>
    </message>
</context>
</TS>